@@ -16,8 +16,15 @@ sub handler {
 
     # Hello world!
     $tx->res->code(200);
-    $tx->res->headers->content_type('text/plain');
-    $tx->res->body('Congratulations, your Mojo is working!');
+    $tx->res->headers->content_type('text/html');
+    $tx->res->body(<<'EOF');
+<html>
+    <head></head>
+    <body>
+        Congratulations, your Mojo is working!
+    </body>
+</html>
+EOF
 
     return $tx;
 }
@@ -27,20 +34,19 @@ __END__
 
 =head1 NAME
 
-Mojo::HelloWorld - Hello World!
+Mojo::HelloWorld - Default Application
 
 =head1 SYNOPSIS
 
-    use Mojo::Transaction;
+    use Curse::Transaction;
     use Mojo::HelloWorld;
 
     my $hello = Mojo::HelloWorld->new;
-    my $tx = $hello->handler(Mojo::Transaction->new);
+    my $tx = $hello->handler(Curse::Transaction->new);
 
 =head1 DESCRIPTION
 
-L<Mojo::HelloWorld> is the default L<Mojo> application, used mostly for
-testing.
+L<Mojo::HelloWorld> is the default L<Mojo> application.
 
 =head1 METHODS
 
