@@ -7,7 +7,7 @@ use warnings;
 
 use base 'Mojo::Script';
 
-use Mojo::Server::Daemon;
+use Curse::Server::Daemon;
 
 __PACKAGE__->attr('description', chained => 1, default => <<'EOF');
 * Start the daemon. *
@@ -24,7 +24,7 @@ sub run {
 
     # Start server
     $port ||= 3000;
-    my $daemon = Mojo::Server::Daemon->new;
+    my $daemon = Curse::Server::Daemon->new;
     $daemon->port($port);
     $daemon->run;
 
@@ -41,14 +41,13 @@ Mojo::Script::Daemon - Daemon Script
 =head1 SYNOPSIS
 
     use Mojo::Script::Daemon;
-
     my $daemon = Mojo::Script::Daemon->new;
     $daemon->run(@ARGV);
 
 =head1 DESCRIPTION
 
-L<Mojo::Script::Daemon> is a script interface to
-L<Mojo::Server::Daemon>.
+L<Mojo::Script::Daemon> is a simple script interface to
+L<Curse::Server::Daemon>.
 
 =head1 ATTRIBUTES
 
